@@ -1,5 +1,4 @@
 import errno
-import importlib.util
 import inspect
 import os
 import sys
@@ -28,8 +27,7 @@ from ._typing import Literal
 MarkupMode = Literal["markdown", "rich", None]
 MARKUP_MODE_KEY = "TYPER_RICH_MARKUP_MODE"
 
-HAS_RICH = importlib.util.find_spec("rich") is not None
-HAS_SHELLINGHAM = importlib.util.find_spec("shellingham") is not None
+HAS_RICH = os.getenv("TYPER_USE_RICH", True)
 
 if HAS_RICH:
     DEFAULT_MARKUP_MODE: MarkupMode = "rich"
